@@ -1,6 +1,8 @@
 import os
 import imp
 import jpype
+import jpype.imports
+from jpype.types import *
 
 if jpype.isJVMStarted() != True:
     jars = []
@@ -10,3 +12,6 @@ if jpype.isJVMStarted() != True:
                 jars.append(os.path.join(top, nm))
     jpype.addClassPath(os.pathsep.join(jars))
     jpype.startJVM(jpype.getDefaultJVMPath(),convertStrings=False)
+    from java.lang import System
+    from java.io import PrintStream, File
+    System.setOut(PrintStream(File(os.devnull)))
